/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 */

#ifndef _AVRDUDE_H
#define _AVRDUDE_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#define AVRDUDE_COMMAND "avrdude"

#define AVRDUDE_OPTION_MEMORY_OP_SPEC "-U"
#define AVRDUDE_OPTION_DISABLE_SAFEMODE "-u"
#define AVRDUDE_OPTION_QUELL_OUTPUT "-q"
#define AVRDUDE_OPTION_PART "-p"
#define AVRDUDE_OPTION_CONFIG_FILE "-C"
#define AVRDUDE_OPTION_PROGRAMMER "-c"
#define AVRDUDE_OPTION_DISABLE_AUTO_ERASE "-D"
#define AVRDUDE_OPTION_PORT "-P"
#define AVRDUDE_OPTION_OVERRIDE_INVALID_SIGNATURE "-F"
#define AVRDUDE_OPTION_PERFORM_CHIP_ERASE "-e"
#define AVRDUDE_OPTION_DO_NOT_VERIFY "-V"

#define AVRDUDE_OP_READ 'r'
#define AVRDUDE_OP_WRITE 'w'
#define AVRDUDE_OP_VERIFY 'v'

#define AVRDUDE_FORMAT_INTEL_HEX "Intel Hex"
#define AVRDUDE_FORMAT_MOTOROLA "Motorola"
#define AVRDUDE_FORMAT_RAW_BINARY "Raw Binary"
#define AVRDUDE_FORMAT_AUTO_DETECT "Auto Detect"

#include <gnome.h>

typedef struct
{
        GString         *part;
        GString         *config_file;
        GString         *programmer;
        GString         *port;
        GString         *memtype;
        GString         *filename;
        gchar           format;
        gboolean        disable_auto_erase;
        gboolean        override_invalid_signature;
        gboolean        perform_chip_erase;
        gboolean        do_not_verify;       
} AvrDudeOptions; 

AvrDudeOptions *avrdude_options_new ();
void avrdude_options_free (AvrDudeOptions *options);

void avrdude_options_set_part (AvrDudeOptions *options, const gchar* value);
void avrdude_options_set_config_file (AvrDudeOptions *options, const gchar* value);
void avrdude_options_set_programmer (AvrDudeOptions *options, const gchar* value);
void avrdude_options_set_port (AvrDudeOptions *options, const gchar* value);
void avrdude_options_set_memtype (AvrDudeOptions *options, const gchar* value);
void avrdude_options_set_filename (AvrDudeOptions *options, const gchar* value); 
void avrdude_options_set_format (AvrDudeOptions *options, const gchar* value);
GString *avrdude_get_command (AvrDudeOptions *options, gchar op);
gboolean avrdude_run (GString *command, GtkTextView *output_text);

void avrdude_debug_dump (AvrDudeOptions *options);

#endif
