/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <glade/glade.h>

#include "dialogs.h"
#include "settings.h"

GtkResponseType
message_dialog(GtkMessageType type, const gchar *message)
{       
        GtkWidget               *dialog=NULL;
        GtkResponseType         response;
    	GtkButtonsType          buttons=GTK_BUTTONS_OK;
        
        if (type == GTK_MESSAGE_QUESTION) buttons = GTK_BUTTONS_YES_NO;
                
    	/* create the dialog */
    	dialog = gtk_message_dialog_new (NULL,
                 	GTK_DIALOG_DESTROY_WITH_PARENT,
                       	type,
                        buttons,
                        message);
                               
        /* show dialog */
 	response = gtk_dialog_run (GTK_DIALOG(dialog));
	gtk_widget_destroy (dialog);   
        
        return response;
}

gchar * 
open_file_dialog()
{
        GladeXML                *gxml=NULL;
        GtkWidget               *dialog=NULL;
        GtkResponseType         response;
        gchar                   *glade_file;
        gchar                   *filename = NULL;
        
        /* setup glade */
        glade_file = gnome_program_locate_file (NULL, 
                        GNOME_FILE_DOMAIN_APP_DATADIR,
                        GLADE_FILENAME, TRUE, NULL);        
        g_assert (glade_file);
        gxml = glade_xml_new (glade_file, "file_chooser_dialog", NULL);
        g_free (glade_file);
        
        /* setup dialog */
        dialog = glade_xml_get_widget (gxml, "file_chooser_dialog");
        gtk_window_set_title(GTK_WINDOW(dialog), _("Open File..."));
        gtk_window_set_icon_name (GTK_WINDOW(dialog), "gtk-open");
        gtk_file_chooser_set_action(GTK_FILE_CHOOSER(dialog), 
                GTK_FILE_CHOOSER_ACTION_OPEN);
        gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(dialog),
                        get_last_filechooser_path ());
                                
        /* present user with a file selection dialog */
 	response = gtk_dialog_run (GTK_DIALOG (dialog));

        if (response == GTK_RESPONSE_OK)
        {
                filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
        }
        
        save_last_filechooser_path (gtk_file_chooser_get_current_folder(
                        GTK_FILE_CHOOSER(dialog)));
                        
        gtk_widget_destroy(dialog);
        
        /* dialog box result is 0 for "quit" */
        return filename;
}

gchar * 
save_file_dialog()
{
        GladeXML                *gxml=NULL;
        GtkWidget               *dialog=NULL;
        GtkResponseType         response;
        gchar                   *glade_file;
        gchar                   *filename = NULL;
        
        /* setup glade */
        glade_file = gnome_program_locate_file (NULL, 
                        GNOME_FILE_DOMAIN_APP_DATADIR,
                        GLADE_FILENAME, TRUE, NULL);        
        g_assert (glade_file);
        gxml = glade_xml_new (glade_file, "file_chooser_dialog", NULL);
        g_free (glade_file);
        
        /* setup dialog */
        dialog = glade_xml_get_widget (gxml, "file_chooser_dialog");
        gtk_window_set_title(GTK_WINDOW(dialog), _("Save File As..."));
        gtk_window_set_icon_name (GTK_WINDOW(dialog), "gtk-save");
        gtk_file_chooser_set_action(GTK_FILE_CHOOSER(dialog), 
                GTK_FILE_CHOOSER_ACTION_SAVE);
        gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(dialog),
                        get_last_filechooser_path ());
                                
        /* present user with a file selection dialog */
 	response = gtk_dialog_run (GTK_DIALOG (dialog));

        if (response == GTK_RESPONSE_OK)
        {
                filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
        }
        
        save_last_filechooser_path (gtk_file_chooser_get_current_folder(
                        GTK_FILE_CHOOSER(dialog)));
                        
        gtk_widget_destroy(dialog);
        
        /* dialog box result is 0 for "quit" */
        return filename;
}

void 
preferences_dialog ()
{
        GladeXML                *gxml=NULL;
        GtkWidget               *dialog=NULL;
        GtkResponseType         response;
        gchar                   *glade_file;
        
        /* setup glade */
        glade_file = gnome_program_locate_file (NULL, 
                        GNOME_FILE_DOMAIN_APP_DATADIR,
                        GLADE_FILENAME, TRUE, NULL);        
        g_assert (glade_file);
        gxml = glade_xml_new (glade_file, "preferences_dialog", NULL);
        g_free (glade_file);
        dialog = glade_xml_get_widget (gxml, "preferences_dialog");
        
        preferences_to_gui (gxml);
        
        response = gtk_dialog_run (GTK_DIALOG(dialog));
        
        if (response == GTK_RESPONSE_OK) 
        {
                /* populate structure from GUI */
                preferences_from_gui (gxml);
        } 
        else if (response == GTK_RESPONSE_HELP)
        {
                message_dialog (GTK_MESSAGE_INFO, "Help not available");
        }        

        /* clean up */
        gtk_widget_destroy (dialog);
}

void 
configure_dialog (AvrDudeOptions *options)
{
        GladeXML                *gxml=NULL;
        GtkWidget               *dialog=NULL;
        GtkResponseType         response;
        gchar                   *glade_file;
        
        /* setup glade */
        glade_file = gnome_program_locate_file (NULL, 
                        GNOME_FILE_DOMAIN_APP_DATADIR,
                        GLADE_FILENAME, TRUE, NULL);        
        g_assert (glade_file);
        gxml = glade_xml_new (glade_file, "configure_dialog", NULL);
        g_free (glade_file);
        
        dialog = glade_xml_get_widget (gxml, "configure_dialog");
        
        avrdude_options_to_gui (options, gxml);
        
        response = gtk_dialog_run (GTK_DIALOG(dialog));
        
        if (response == GTK_RESPONSE_OK) 
        {
                /* populate structure from GUI */
                avrdude_options_from_gui (options, gxml);
                
                /* save options */
                save_avrdude_options (options);
        } 
        else if (response == GTK_RESPONSE_HELP)
        {
                message_dialog (GTK_MESSAGE_INFO, "Help not available");
        }        

        /* clean up */
        gtk_widget_destroy (dialog);
}

void 
about_dialog ()
{
        GladeXML                *gxml=NULL;
        GtkWidget               *dialog=NULL;
        gchar                   *glade_file;
        
        /* setup glade */
        glade_file = gnome_program_locate_file (NULL, 
                        GNOME_FILE_DOMAIN_APP_DATADIR,
                        GLADE_FILENAME, TRUE, NULL);        
        g_assert (glade_file);
        gxml = glade_xml_new (glade_file, "about_dialog", NULL);
        g_free (glade_file);
        
        dialog = glade_xml_get_widget (gxml, "about_dialog");
        
        gtk_about_dialog_set_version (GTK_ABOUT_DIALOG(dialog), VERSION);
        gtk_dialog_run (GTK_DIALOG(dialog));
        
        /* clean up */
        gtk_widget_destroy (dialog);
}

GtkWidget *
show_running_dialog (gchar op)
{
        GladeXML                *gxml=NULL;
        GtkWidget               *window=NULL;
        GtkWidget               *image=NULL;
        gchar                   *glade_file;
        gchar                   *image_file;
        
        /* setup glade */
        glade_file = gnome_program_locate_file (NULL, 
                        GNOME_FILE_DOMAIN_APP_DATADIR,
                        GLADE_FILENAME, TRUE, NULL);        
        g_assert (glade_file);
        gxml = glade_xml_new (glade_file, "running_dialog", NULL);
        g_free (glade_file);
        
        window = glade_xml_get_widget (gxml, "running_dialog");
        image = glade_xml_get_widget (gxml, "image");
        
        if (op == AVRDUDE_OP_READ)
        {
                gtk_window_set_title (GTK_WINDOW(window), _("Reading..."));
                image_file = gnome_program_locate_file (NULL, 
                                GNOME_FILE_DOMAIN_APP_DATADIR,
                                IMAGE_READ, FALSE, NULL);
                gtk_image_set_from_file (GTK_IMAGE(image), image_file);
                g_debug ("%s", image_file);
                g_free (image_file);
        }
        
        gtk_window_set_keep_above (GTK_WINDOW(window), TRUE);
        gtk_widget_show_now (window);
        
        while (gtk_events_pending()) gtk_main_iteration();
        
        return window;
}
