/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <glade/glade.h>
#include <gconf/gconf-client.h>

#include "callbacks.h"
#include "settings.h"
#include "dialogs.h"
#include "avrdude.h"

int
main (int argc, char *argv[])
{
	GnomeProgram   *program=NULL;
	gchar          *glade_file=NULL;
	gchar          *icon_file=NULL;
	GtkWidget      *app_window=NULL;
        CallBackData   *cb_data = g_new (CallBackData, 1);
         
        /* initializations */
        cb_data->options = avrdude_options_new ();
        cb_data->gxml = NULL;
        
	program = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
                      argc, argv,
                      GNOME_PROGRAM_STANDARD_PROPERTIES,
                      NULL);
                      
        gconf_init(argc, argv, NULL);
        
        
        /* setup glade */
        glade_file = gnome_program_locate_file (program, 
                        GNOME_FILE_DOMAIN_APP_DATADIR,
                        GLADE_FILENAME, TRUE, NULL);        
        g_assert (glade_file);
        cb_data->gxml = glade_xml_new (glade_file, "app_window", NULL);
        g_free (glade_file);

        
        /* setup main application window */  
        app_window = glade_xml_get_widget (cb_data->gxml, "app_window");
                            
        restore_window_position (GTK_WINDOW(app_window));

        icon_file = gnome_program_locate_file (program, 
                        GNOME_FILE_DOMAIN_PIXMAP,
                        ICON_FILENAME, FALSE, NULL); 
        gtk_window_set_icon_from_file (GTK_WINDOW(app_window), icon_file, NULL);
        g_free (icon_file);
        
        apply_preferences (cb_data->gxml);
        
        /* connect signal callbacks */
        glade_xml_signal_connect (cb_data->gxml, "on_app_window_destroy", 
                G_CALLBACK(on_app_window_destroy));
        
        glade_xml_signal_connect (cb_data->gxml, "on_app_window_delete_event", 
                G_CALLBACK(on_app_window_delete_event));
        
        glade_xml_signal_connect_data (cb_data->gxml, "on_open_activate", 
                G_CALLBACK(on_open_activate), cb_data);
                
        glade_xml_signal_connect_data (cb_data->gxml, "on_preferences_activate", 
                G_CALLBACK(on_preferences_activate), cb_data);
                
        glade_xml_signal_connect_data (cb_data->gxml, "on_read_activate", 
                G_CALLBACK(on_read_activate), cb_data);
        
        glade_xml_signal_connect_data (cb_data->gxml, "on_write_activate", 
                G_CALLBACK(on_write_activate), cb_data);
        
        glade_xml_signal_connect_data (cb_data->gxml, "on_verify_activate", 
                G_CALLBACK(on_verify_activate), cb_data);
                        
        glade_xml_signal_connect_data (cb_data->gxml, "on_quit_activate", 
                G_CALLBACK(on_quit_activate), app_window);
                
        glade_xml_signal_connect_data (cb_data->gxml, "on_configure_activate", 
                G_CALLBACK(on_configure_activate), cb_data);
        
        glade_xml_signal_connect_data (cb_data->gxml, "on_about_activate", 
                G_CALLBACK(on_about_activate), cb_data->options);


        /* get saved avrdude options */
        get_avrdude_options (cb_data->options);
        set_appbar_default (cb_data->gxml, cb_data->options);
        
        gtk_widget_show (app_window);

	gtk_main ();
        
        avrdude_options_free (cb_data->options);
        
	return 0;
}


