/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <glade/glade.h>
#include <gconf/gconf-client.h>

#include "settings.h"
#include "dialogs.h"

void
restore_window_position (GtkWindow *window)
{
        /* restore window size and position */
        GConfClient *client = gconf_client_get_default ();
        gint x=0,y=0,w=0,h=0;
        
	x = gconf_client_get_int (client, GCONF_PATH"/window_x", NULL);
    	y = gconf_client_get_int (client, GCONF_PATH"/window_y", NULL);
    	w = gconf_client_get_int (client, GCONF_PATH"/window_width", NULL);
    	h = gconf_client_get_int (client, GCONF_PATH"/window_height", NULL);
        
        if (w <= 0) w = DEFAULT_WINDOW_WIDTH;
        if (h <= 0) h = DEFAULT_WINDOW_HEIGHT;
        
	gtk_window_move (window, x, y);
	gtk_window_set_default_size (window, w, h);
}

void 
save_window_position(GtkWindow *window)
{
        GConfClient *client = gconf_client_get_default ();
        gint x=0,y=0,w=0,h=0;
       	
    	gtk_window_get_size (window, &w, &h);
    	gtk_window_get_position (window, &x, &y);
        
        if (w <= 0) w = DEFAULT_WINDOW_WIDTH;
        if (h <= 0) h = DEFAULT_WINDOW_HEIGHT;
        
        gconf_client_set_int (client, GCONF_PATH"/window_x", x, NULL);
        gconf_client_set_int (client, GCONF_PATH"/window_y", y, NULL);
        gconf_client_set_int (client, GCONF_PATH"/window_width", w, NULL);
        gconf_client_set_int (client, GCONF_PATH"/window_height", h, NULL);
}

void 
save_last_filechooser_path (const gchar *path)
{
        GConfClient *client = gconf_client_get_default ();
        gconf_client_set_string (client, GCONF_PATH"/filechooser_path", 
                        path, NULL);
}

const gchar *
get_last_filechooser_path ()
{
        GConfClient *client = gconf_client_get_default ();
        const gchar *path = gconf_client_get_string (client, 
                        GCONF_PATH"/filechooser_path", NULL);
        if (!path)
        {
                path = g_get_home_dir ();
        }
        
        return path;
}

void 
save_avrdude_options (AvrDudeOptions *o)
{
        GConfClient *client = gconf_client_get_default ();
                
        gconf_client_set_string (client, GCONF_PATH"/avrdude_part", 
                        o->part->str, NULL);
 
        gconf_client_set_string (client, GCONF_PATH"/avrdude_programmer", 
                        o->programmer->str, NULL);
        
        gconf_client_set_string (client, GCONF_PATH"/avrdude_port", 
                        o->port->str, NULL);
                        
        gconf_client_set_string (client, GCONF_PATH"/avrdude_memtype", 
                        o->memtype->str, NULL);
                        
        gconf_client_set_int (client, GCONF_PATH"/avrdude_format", 
                        o->format, NULL);
                        
        gconf_client_set_bool (client, GCONF_PATH"/avrdude_disable_auto_erase", 
                        o->disable_auto_erase, NULL);
                        
        gconf_client_set_bool (client, GCONF_PATH"/avrdude_override_invalid_signature", 
                        o->override_invalid_signature, NULL);
        
        gconf_client_set_bool (client, GCONF_PATH"/avrdude_perform_chip_erase", 
                        o->perform_chip_erase, NULL);
        
        gconf_client_set_bool (client, GCONF_PATH"/avrdude_do_not_verify", 
                        o->do_not_verify, NULL);      
}

void 
get_avrdude_options (AvrDudeOptions *o)
{
        GConfClient     *client = gconf_client_get_default ();
        gchar           *temp;
        
        temp = gconf_client_get_string (client, 
                        GCONF_PATH"/avrdude_part", NULL);
        avrdude_options_set_part (o, temp);
        if (temp) g_free (temp);
        
        temp = gconf_client_get_string (client, 
                        GCONF_PATH"/avrdude_programmer", NULL);
        avrdude_options_set_programmer (o, temp);
        if (temp) g_free (temp);
        
        temp = gconf_client_get_string (client, 
                        GCONF_PATH"/avrdude_port", NULL);
        avrdude_options_set_port (o, temp);
        if (temp) g_free (temp);
        
        temp = gconf_client_get_string (client, 
                        GCONF_PATH"/avrdude_memtype", NULL);
        avrdude_options_set_memtype (o, temp);
        if (temp) g_free (temp);
        
        o->format = gconf_client_get_int (client, 
                        GCONF_PATH"/avrdude_format", NULL);
        
        o->disable_auto_erase = gconf_client_get_bool (client, 
                        GCONF_PATH"/avrdude_disable_auto_erase", NULL);
                        
        o->override_invalid_signature = gconf_client_get_bool (client, 
                        GCONF_PATH"/avrdude_override_invalid_signature", NULL);
        
        o->perform_chip_erase = gconf_client_get_bool (client, 
                        GCONF_PATH"/avrdude_perform_chip_erase", NULL);
        
        o->do_not_verify = gconf_client_get_bool (client, 
                        GCONF_PATH"/avrdude_do_not_verify", NULL);
      
}

void 
set_appbar_default (GladeXML *gxml, AvrDudeOptions *o)
{
        GtkWidget *appbar = glade_xml_get_widget (gxml, "main_appbar");
        GString *status = g_string_new_len (NULL, 1);
        
        g_string_printf (status, 
                        "Programmer: %s  Port: %s  Part: %s  File: %s",
                        o->programmer->str, 
                        o->port->str,
                        o->part->str,
                        g_path_get_basename(o->filename->str)); 
                        
       gnome_appbar_set_default (GNOME_APPBAR(appbar), status->str);
}

gboolean 
load_file_into_textview (const gchar *filename, GtkTextView *text_view)
{
        GtkTextBuffer *text_buffer;
        GError *err;
        gsize bytes;
        gboolean result;
        gchar *temp_buffer=NULL;
        
        result = g_file_get_contents (filename, &temp_buffer, &bytes, &err);
        
        if (!result)
        {
                GString *msg = g_string_new (_("Could not open file:\n"));
                msg = g_string_append (msg, filename);
                msg = g_string_append (msg, "\n");
                msg = g_string_append (msg, err->message);
                
                g_warning (_("Could not open file: %s\n%s"), filename, 
                                err->message);
                message_dialog (GTK_MESSAGE_ERROR, msg->str);

                g_error_free (err);
                g_string_free (msg, TRUE);
                
                return FALSE;
        }
        
        if (g_utf8_validate(temp_buffer, -1, NULL))
        {
                text_buffer = gtk_text_view_get_buffer (text_view);
                gtk_text_buffer_set_text (text_buffer, temp_buffer, -1);
        }
        else
        {
                GString *msg = g_string_new (_("Could not open file:\n"));
                msg = g_string_append (msg, filename);
                msg = g_string_append (msg, "\n");
                msg = g_string_append (msg, _("Not valid UTF-8 encoding."));
                
                g_warning (_("Could not open file: %s\nNot valid UTF-8 encoding."), 
                                filename);
                message_dialog (GTK_MESSAGE_ERROR, msg->str);

                g_string_free (msg, TRUE);
                g_free (temp_buffer);
                
                return FALSE;
                        
        }
        
        g_free (temp_buffer);                                
        return TRUE;
}

void preferences_to_gui (GladeXML *gxml)
{
        GConfClient     *client = gconf_client_get_default ();
        GtkWidget       *w = NULL;
        gint            toolbar_style;
        
        toolbar_style = gconf_client_get_int (client, 
                        GCONF_PATH"/toolbar_style", NULL);
        w = glade_xml_get_widget (gxml, "toolbar_style");
        gtk_combo_box_set_active (GTK_COMBO_BOX(w), toolbar_style);                
        
        w = NULL;
        w = glade_xml_get_widget (gxml, "font_button"); 
        gchar *font = gconf_client_get_string (client, 
                        GCONF_PATH"/font", NULL);   
        if (font) 
        {
                gtk_font_button_set_font_name (GTK_FONT_BUTTON(w), font);
        }
        else
        {
                gtk_font_button_set_font_name (GTK_FONT_BUTTON(w),
                                DEFAULT_FONT_STRING);
        }
         
        g_free (font);
}

void preferences_from_gui (GladeXML *gxml)
{
        GConfClient     *client = gconf_client_get_default ();
        GtkWidget       *w = NULL;
        
        w = glade_xml_get_widget (gxml, "toolbar_style");
        gint toolbar_style = gtk_combo_box_get_active (GTK_COMBO_BOX(w));
        gconf_client_set_int (client, GCONF_PATH"/toolbar_style", 
                        toolbar_style, NULL);
                        
        w = NULL;
        w = glade_xml_get_widget (gxml, "font_button");
        const gchar *font = gtk_font_button_get_font_name (GTK_FONT_BUTTON(w));
        gconf_client_set_string (client, GCONF_PATH"/font", 
                        font, NULL);
          
}

void apply_preferences (GladeXML *gxml)
{
        GConfClient             *client = gconf_client_get_default ();
        GtkWidget               *w = NULL;
        GtkWidget               *dock = NULL;
        PangoFontDescription    *font_desc;
        
        gchar *font = gconf_client_get_string (client, 
                        GCONF_PATH"/font", NULL);   
        font_desc = pango_font_description_from_string (font);
        g_free (font);
        
        w = glade_xml_get_widget (gxml, "output_text"); 
        gtk_widget_modify_font (w, font_desc);      
        
        gint toolbar_style = gconf_client_get_int (client, 
                        GCONF_PATH"/toolbar_style", NULL); 
        w = NULL;
        w = glade_xml_get_widget (gxml, "toolbar");
        dock = glade_xml_get_widget (gxml, "toolbar_dock");
        
        if (toolbar_style == TOOLBAR_STYLE_ICONS_ONLY)
                gtk_toolbar_set_style (GTK_TOOLBAR(w), GTK_TOOLBAR_ICONS);
        else if (toolbar_style == TOOLBAR_STYLE_TEXT_ONLY)
                gtk_toolbar_set_style (GTK_TOOLBAR(w), GTK_TOOLBAR_TEXT);
        else if (toolbar_style == TOOLBAR_STYLE_TEXT_ICONS)
                gtk_toolbar_set_style (GTK_TOOLBAR(w), GTK_TOOLBAR_BOTH);     
        else if (toolbar_style == TOOLBAR_STYLE_GNOME_DEFAULT)
                gtk_toolbar_unset_style (GTK_TOOLBAR(w));
        
        if (toolbar_style == TOOLBAR_STYLE_HIDE) gtk_widget_hide (dock);
        else gtk_widget_show (dock);
}

void 
avrdude_options_from_gui (AvrDudeOptions *options, GladeXML *gxml)
{
        /* move values from dialog to structure */
        GtkWidget *w;
        gboolean b;
        
        /* part */
        w=NULL;
        w = glade_xml_get_widget (gxml, "part");
        avrdude_options_set_part (options,
                        gtk_combo_box_get_active_text (GTK_COMBO_BOX(w)));
        
        /* config file */
        w=NULL;
        w = glade_xml_get_widget (gxml, "config_file");
        avrdude_options_set_config_file (options,
                        gtk_combo_box_get_active_text (GTK_COMBO_BOX(w)));
        
        /* programmer */
        w=NULL;
        w = glade_xml_get_widget (gxml, "programmer");
        avrdude_options_set_programmer (options,
                        gtk_combo_box_get_active_text (GTK_COMBO_BOX(w)));
        
        /* port */
        w=NULL;
        w = glade_xml_get_widget (gxml, "port");
        avrdude_options_set_port (options,
                        gtk_combo_box_get_active_text (GTK_COMBO_BOX(w)));
                        
        
        /* memtype */
        w=NULL;
        w = glade_xml_get_widget (gxml, "memtype");
        avrdude_options_set_memtype (options,
                        gtk_combo_box_get_active_text (GTK_COMBO_BOX(w)));
        
        /* format */
        w=NULL;
        w = glade_xml_get_widget (gxml, "format");
        avrdude_options_set_format (options,
                        gtk_combo_box_get_active_text (GTK_COMBO_BOX(w)));
        
        /* diable auto erase */
        w=NULL;
        w = glade_xml_get_widget (gxml, "disable_auto_erase");
        b = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(w));
        options->disable_auto_erase = b;
        
        /* override invalid signature */
        w=NULL;
        w = glade_xml_get_widget (gxml, "override_invalid_signature");
        b = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(w));
        options->override_invalid_signature = b;
        
        /* perform_chip_erase */
        w=NULL;
        w = glade_xml_get_widget (gxml, "perform_chip_erase");
        b = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(w));
        options->perform_chip_erase = b;
        
        /* do not verify */
        w=NULL;
        w = glade_xml_get_widget (gxml, "do_not_verify");
        b = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(w));
        options->do_not_verify = b;
                                        
        avrdude_debug_dump (options);
}

void 
avrdude_options_to_gui (AvrDudeOptions *options, GladeXML *gxml)
{
        /* move values from dialog to structure */
        GtkWidget *w;
        GtkWidget *entry;
        
        /* part */
        w=NULL;
        entry=NULL;
        w = glade_xml_get_widget (gxml, "part");
        entry = gtk_bin_get_child (GTK_BIN(w));
        gtk_entry_set_text (GTK_ENTRY (entry), options->part->str);
        
        /* config file */
        w=NULL;
        entry=NULL;
        w = glade_xml_get_widget (gxml, "config_file");
        entry = gtk_bin_get_child (GTK_BIN(w));
        gtk_entry_set_text (GTK_ENTRY (entry), options->config_file->str);
        
        /* programmer */
        w=NULL;
        entry=NULL;
        w = glade_xml_get_widget (gxml, "programmer");
        entry = gtk_bin_get_child (GTK_BIN(w));
        gtk_entry_set_text (GTK_ENTRY (entry), options->programmer->str);
        
        /* port */
        w=NULL;
        entry=NULL;
        w = glade_xml_get_widget (gxml, "port");
        entry = gtk_bin_get_child (GTK_BIN(w));
        gtk_entry_set_text (GTK_ENTRY (entry), options->port->str);
        
        /* memtype */
        w=NULL;
        entry=NULL;
        w = glade_xml_get_widget (gxml, "memtype");
        entry = gtk_bin_get_child (GTK_BIN(w));
        gtk_entry_set_text (GTK_ENTRY (entry), options->memtype->str);
        
        /* format */
        w=NULL;
        entry=NULL;
        w = glade_xml_get_widget (gxml, "format");
        entry = gtk_bin_get_child (GTK_BIN(w));
        if (options->format == 'i')
                gtk_entry_set_text (GTK_ENTRY (entry), AVRDUDE_FORMAT_INTEL_HEX);
        else if (options->format == 'm')
                gtk_entry_set_text (GTK_ENTRY (entry), AVRDUDE_FORMAT_MOTOROLA);
        else if (options->format == 'r')
                gtk_entry_set_text (GTK_ENTRY (entry), AVRDUDE_FORMAT_RAW_BINARY);
        else if (options->format == 'a')
                gtk_entry_set_text (GTK_ENTRY (entry), AVRDUDE_FORMAT_AUTO_DETECT);
                
        /* diable auto erase */
        w=NULL;
        w = glade_xml_get_widget (gxml, "disable_auto_erase");
        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), 
                        options->disable_auto_erase);
    
        /* override invalid signature */
        w=NULL;
        w = glade_xml_get_widget (gxml, "override_invalid_signature");
        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w),
                        options->override_invalid_signature);
        
        /* perform_chip_erase */
        w=NULL;
        w = glade_xml_get_widget (gxml, "perform_chip_erase");
        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w),
                        options->perform_chip_erase);
        
        /* do not verify */
        w=NULL;
        w = glade_xml_get_widget (gxml, "do_not_verify");
        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w),
                        options->do_not_verify);

}




