/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 */

#ifndef _SETTINGS_H
#define _SETTINGS_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <glade/glade.h>
#include <gconf/gconf-client.h>

#include "avrdude.h"

#define GCONF_PATH "/apps/"PACKAGE
#define DEFAULT_WINDOW_WIDTH 500
#define DEFAULT_WINDOW_HEIGHT 400

#define DEFAULT_FONT_STRING "monospace 10"
#define TOOLBAR_STYLE_GNOME_DEFAULT 0
#define TOOLBAR_STYLE_ICONS_ONLY 1
#define TOOLBAR_STYLE_TEXT_ONLY 2
#define TOOLBAR_STYLE_TEXT_ICONS 3
#define TOOLBAR_STYLE_HIDE 4

#define GLADE_FILENAME PACKAGE"/"PACKAGE".glade"
#define ICON_FILENAME "gnome-avrdude.png"

#define IMAGE_READ PACKAGE"/avr_read.png"
#define IMAGE_WRITE PACKAGE"/avr_write.png"
#define IMAGE_VERIFY PACKAGE"/avr_verify.png"

#define TEMP_BUFFER_SIZE 1024
#define TEXT_BUFFER_SIZE 8192
#define NOTEBOOK_PAGE_OUTPUT 0
#define NOTEBOOK_PAGE_FILE 1

typedef struct
{
        GladeXML *gxml;
        AvrDudeOptions *options;     
} CallBackData; 

void restore_window_position (GtkWindow *window);
void save_window_position (GtkWindow *window);

void save_last_filechooser_path (const gchar *path);
const gchar *get_last_filechooser_path ();

void save_avrdude_options (AvrDudeOptions *o);
void get_avrdude_options (AvrDudeOptions *o);

void set_appbar_default (GladeXML *gxml, AvrDudeOptions *o);

gboolean load_file_into_textview (const gchar *filename, GtkTextView *text_view);

void preferences_to_gui (GladeXML *gxml);
void preferences_from_gui (GladeXML *gxml);
void apply_preferences (GladeXML *gxml);

void avrdude_options_from_gui (AvrDudeOptions *options, GladeXML *gxml);
void avrdude_options_to_gui (AvrDudeOptions *options, GladeXML *gxml); 


#endif /* _SETTINGS_H */
